@@ -1,6 +1,5 @@
 """Column names to use across datasets, used for processing."""
 
-
 ENCOUNTER_ID = "encounter_id"
 SUBJECT_ID = "subject_id"
 HOSPITAL_ID = "hospital_id"
@@ -48,29 +47,3 @@ RESTRICT_TIMESTAMP = "restrict_timestamp"
 
 REFERENCE_RANGE = "reference_range"
 TIMESTEP = "timestep"
-
-RECOGNISED_QUERY_COLUMNS = [
-    ADMIT_TIMESTAMP,
-    DISCHARGE_TIMESTAMP,
-    ENCOUNTER_ID,
-    EVENT_NAME,
-    EVENT_TIMESTAMP,
-    EVENT_VALUE,
-    EVENT_VALUE_UNIT,
-    LENGTH_OF_STAY_IN_ER,
-    SEX,
-    HOSPITAL_ID,
-    DIAGNOSIS_CODE,
-    DIAGNOSIS_TYPE,
-    YEAR,
-    AGE,
-]
-RECOGNISED_EVENT_COLUMNS = [
-    ADMIT_TIMESTAMP,
-    DISCHARGE_TIMESTAMP,
-    ENCOUNTER_ID,
-    EVENT_NAME,
-    EVENT_TIMESTAMP,
-    EVENT_VALUE,
-    EVENT_VALUE_UNIT,
-]
